        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 20 <br>1,2,6,9,18,19,21,22,23,31,35,38,39,40,43,44,45,46,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 12 <br>8,11,12,16,17,20,25,27,29,30,36,42';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 12 <strong>control</strong><br>0,4,7,10,15,24,26,28,34,37,47,48';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 7 <br>3,5,13,14,32,33,41';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 20 <br>1,2,6,9,18,19,21,22,23,31,35,38,39,40,43,44,45,46,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 12 <br>8,11,12,16,17,20,25,27,29,30,36,42';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 12 <strong>control</strong><br>0,4,7,10,15,24,26,28,34,37,47,48';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 7 <br>3,5,13,14,32,33,41';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 20 <br>1,2,6,9,18,19,21,22,23,31,35,38,39,40,43,44,45,46,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 12 <br>8,11,12,16,17,20,25,27,29,30,36,42';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 12 <strong>control</strong><br>0,4,7,10,15,24,26,28,34,37,47,48';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 7 <br>3,5,13,14,32,33,41';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 20 <br>1,2,6,9,18,19,21,22,23,31,35,38,39,40,43,44,45,46,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 12 <br>8,11,12,16,17,20,25,27,29,30,36,42';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 12 <strong>control</strong><br>0,4,7,10,15,24,26,28,34,37,47,48';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 7 <br>3,5,13,14,32,33,41';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>23</strong> miembros: 20 <br>1,2,6,9,18,19,21,22,23,31,35,38,39,40,43,44,45,46,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 12 <br>8,11,12,16,17,20,25,27,29,30,36,42';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 12 <strong>control</strong><br>0,4,7,10,15,24,26,28,34,37,47,48';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260629 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 7 <br>3,5,13,14,32,33,41';}
}
